@@ -4,8 +4,10 @@ import {
   OpenAssessmentBlock,
   CourseOpenResponsesListingBlock,
   StaffAssessmentBlock,
+  WaitingStepDetailsBlock,
 } from './lms/oa_base';
 
 window.OpenAssessmentBlock = OpenAssessmentBlock;
 window.CourseOpenResponsesListingBlock = CourseOpenResponsesListingBlock;
 window.StaffAssessmentBlock = StaffAssessmentBlock;
+window.WaitingStepDetailsBlock = WaitingStepDetailsBlock;
